/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */

 




package org.greenstone.gatherer.gui.combobox;

import java.util.Collections;
import java.util.Hashtable;
import java.util.Vector;

import javax.swing.AbstractListModel;
import javax.swing.MutableComboBoxModel;
import org.greenstone.gatherer.msm.ElementWrapper;
import org.w3c.dom.Element;

public class GComboBoxModel
	 extends AbstractListModel
	 implements MutableComboBoxModel {

	 // Data.
	 private boolean   isMetadataElement = false;

	 private Hashtable name_to_element   = new Hashtable();

	 private Object    selected_item     = null;

	 private Vector    contents          = new Vector();

	 public GComboBoxModel() {
	 }

	 public GComboBoxModel(Vector contents) {
		  this.contents = contents;
		  Collections.sort(contents);
	 }

	 public GComboBoxModel(Vector elements, boolean isMetadataElement) {
		  this.isMetadataElement = isMetadataElement;
		  for(int i = 0; i < elements.size(); i++) {
				ElementWrapper element = (ElementWrapper)elements.get(i);
				contents.add(element.toString());
				name_to_element.put(element.toString(), element);
		  }
		  Collections.sort(contents);
	 }

	 private boolean contains(Vector vector, Object key) {
		  for(int i = 0; i < vector.size(); i++) {
				if(vector.get(i).toString().equals(key.toString())) {
					 return true;
				}
		  }
		  return false;
	 }

	 // Methods.
	 public void addElement(Object obj) {
		  if(!contents.contains(obj)) {
				contents.add(obj);
				Collections.sort(contents);
				refresh();
		  }
	 }

	 public Object getElementAt(int index) {
		  return contents.get(index);
	 }

	 public Object getSelectedItem() {
		  return selected_item;
	 }

	 public ElementWrapper getSelectedMetadata() {
		  if(isMetadataElement) {
				return (ElementWrapper)name_to_element.get(selected_item);
		  }
		  return null;
	 }

	 public int getSize() {
		  return contents.size();
	 }

	 public void insertElementAt(Object obj, int index) {
		  contents.add(index, obj);
		  fireIntervalAdded(this, index, index);
	 }

	 public void refresh() {
		  fireContentsChanged(this, 0, getSize());
	 }

	 public void removeElement(Object obj) {
		  int index = contents.indexOf(obj);
		  contents.remove(index);
		  fireIntervalRemoved(this, index, index);
	 }

	 public void removeElementAt(int index) {
		  contents.remove(index);
		  fireIntervalRemoved(this, index, index);
	 }

	 public void setSelectedItem(Object obj) {
		  selected_item = obj;
		  int index = contents.indexOf(obj);
		  fireContentsChanged(this, index, index);
	 }
}
