/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */

 




package org.greenstone.gatherer.help;
/**
 * Title:        The Gatherer<br>
 * Description:  The Gatherer: a tool for gathering and enriching digital collections.<br>
 * Copyright:    Copyright (c) 2001<br>
 * Company:      The University of Waikato<br>
 * @author John Thompson, Greenstone Digital Libraries
 * @version 2.1
 */
import calpa.html.CalHTMLPane; 
import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Toolkit;
import java.io.File;
import java.net.URL;
import java.util.StringTokenizer;
import javax.swing.BorderFactory;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.JTabbedPane;
import javax.swing.JTree;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.tree.TreePath;
import org.greenstone.gatherer.help.ContentModel;
import org.greenstone.gatherer.help.HelpItem;
/** This class provides a nice help facility for the Gatherer tool. It
 * is a separate frame that can be positioned as the user wishes, and provides
 * standard help-type functionality such as contents, index and search, 
 * glossary and of course help descriptions. <BR>
 */
public class HelpFrame 
	 extends JFrame {
	 /** The html rendering pane. */
	 private CalHTMLPane view = null;
	 private ContentModel model = null;
	 
	 private JSplitPane split_pane = null;
	 /** A contents tree for the left of the frame. */
	 private JTree contents = null;
	 /** The size of a button on this pane. */
	 static final Dimension BUTTON_SIZE = new Dimension(100,50);
	 /** The minimum size of any component in this frame. */
	 static final Dimension MIN_SIZE = new Dimension(100,100);
	 /** The size of the frame itself. */
	 static final Dimension SIZE = new Dimension(760,560);
	 /** Constructor.
	  * @param file_name The file name, as a <Strong>String</strong> of the help page to initially show.
	  */
	 public HelpFrame() { 
		  setDefaultCloseOperation(HIDE_ON_CLOSE); 
		  setSize(SIZE);
		  model = new ContentModel();
		  contents = new JTree(model);
		  contents.addTreeSelectionListener(new ContentsListener());
		  contents.setExpandsSelectedPaths(true);
		  view = new CalHTMLPane();
		  // Creation
		  JPanel content_pane = (JPanel) this.getContentPane();
		  split_pane = new JSplitPane(JSplitPane.VERTICAL_SPLIT);
		  JScrollPane index_scroll = new JScrollPane(contents);
		  JScrollPane view_scroll = new JScrollPane(view);
		  // Layout
		  split_pane.add(index_scroll, JSplitPane.LEFT);
		  split_pane.add(view_scroll, JSplitPane.RIGHT);
		  content_pane.setLayout(new BorderLayout());
		  content_pane.add(split_pane, BorderLayout.CENTER);
		  // Center
		  Dimension screen_size = Toolkit.getDefaultToolkit().getScreenSize();
		  setLocation((screen_size.width - SIZE.width) / 2, (screen_size.height - SIZE.height) / 2);		  
	 }
	 /** Destructor. Removes all listeners, closes streams and explicitly sets data members to null. */
	 public void destroy() {
		  view = null;
		  contents = null;
	 }
	 public void setView(String index) {
		  try {
				// Retrieve the node at index
				HelpItem current = (HelpItem) model.getRoot();
				StringTokenizer tokenizer = new StringTokenizer(index, ".");
				while(tokenizer.hasMoreTokens()) {
					 String token = tokenizer.nextToken();
					 int position = Integer.parseInt(token);
					 if(position > 0 && position <= current.getChildCount()) {
						  current = (HelpItem) current.getChildAt(position - 1);
					 }
					 token = null;
				}
				tokenizer = null;
				// Ensure path is selected
				TreePath path = new TreePath(current.getPath());
				contents.setSelectionPath(path);
				contents.scrollPathToVisible(path);
				path = null;
				// Build url
				URL url = current.getURL();
				current = null;
				// Show help dialog
				show();
				split_pane.setDividerLocation(0.2);
				// Display help page
				if(url != null) {
					 view.showHTMLDocument(url);
				}
				url = null;
		  }
		  catch (Exception error) {
				show();
				split_pane.setDividerLocation(0.2);
		  }
	 }

	 /** This listener is used to lister for selection changes in the contents tree, and to show the appropriate page as required.
	  */
	 private class ContentsListener 
		  implements TreeSelectionListener {
		  /** Any implementation of <i>TreeSelectionListener</i> must include this method so we can be informed when the tree selection changes.
			* @param event A <strong>TreeSelectionEvent</strong> containing al the relevant information about the event itself.
			*/
		  public void valueChanged(TreeSelectionEvent event) {
				TreePath path = event.getPath();
				HelpItem node = (HelpItem)path.getLastPathComponent();
				URL url = node.getURL();
				if(url != null) {
					 view.showHTMLDocument(url);
				}
		  }
	 }
}
